@@ -2,6 +2,7 @@ from pluggy import HookimplMarker
 
 from testit_python_commons.services.adapter_manager import AdapterManager
 from testit_python_commons.services.plugin_manager import TmsPluginManager
+from testit_python_commons.services.step_manager import StepManager
 from testit_python_commons.services.utils import Utils
 
 hookimpl = HookimplMarker("testit")
@@ -9,6 +10,7 @@ hookimpl = HookimplMarker("testit")
 __all__ = [
     'AdapterManager',
     'TmsPluginManager',
+    'StepManager',
     'Utils',
     'hookimpl'
 ]
